@@ -1,13 +1,13 @@
 import io
 import itertools
 import math
+import operator
 import uuid
 import warnings
 from collections import defaultdict
 from collections.abc import Iterable, Iterator
 from distutils.version import LooseVersion
 from functools import wraps, partial
-from operator import getitem
 from random import Random
 from urllib.request import urlopen
 
@@ -81,7 +81,9 @@ from ..utils import (
     ensure_dict,
     ensure_bytes,
     ensure_unicode,
+    key_split,
 )
+from . import chunk
 
 
 no_default = "__no__default__"
@@ -318,7 +320,7 @@ class StringAccessor(object):
         return sorted(set(dir(type(self)) + dir(str)))
 
     def _strmap(self, key, *args, **kwargs):
-        return self._bag.map(lambda s: getattr(s, key)(*args, **kwargs))
+        return self._bag.map(operator.methodcaller(key, *args, **kwargs))
 
     def __getattr__(self, key):
         try:
@@ -491,8 +493,7 @@ class Bag(DaskMethodsMixin):
         return type(self), (self.name, self.npartitions)
 
     def __str__(self):
-        name = self.name if len(self.name) < 10 else self.name[:7] + "..."
-        return "dask.bag<%s, npartitions=%d>" % (name, self.npartitions)
+        return "dask.bag<%s, npartitions=%d>" % (key_split(self.name), self.npartitions)
 
     __repr__ = __str__
 
@@ -664,10 +665,10 @@ class Bag(DaskMethodsMixin):
         --------
         >>> import dask.bag as db
         >>> b = db.from_sequence(range(5))
-        >>> list(b.random_sample(0.5, 42))
-        [1, 3]
-        >>> list(b.random_sample(0.5, 42))
-        [1, 3]
+        >>> list(b.random_sample(0.5, 43))
+        [0, 3, 4]
+        >>> list(b.random_sample(0.5, 43))
+        [0, 3, 4]
         """
         if not 0 <= prob <= 1:
             raise ValueError("prob must be a number in the interval [0, 1]")
@@ -1085,22 +1086,9 @@ class Bag(DaskMethodsMixin):
 
     def var(self, ddof=0):
         """ Variance """
-
-        def var_chunk(seq):
-            squares, total, n = 0.0, 0.0, 0
-            for x in seq:
-                squares += x ** 2
-                total += x
-                n += 1
-            return squares, total, n
-
-        def var_aggregate(x):
-            squares, totals, counts = list(zip(*x))
-            x2, x, n = float(sum(squares)), float(sum(totals)), sum(counts)
-            result = (x2 / n) - (x / n) ** 2
-            return result * n / (n - ddof)
-
-        return self.reduction(var_chunk, var_aggregate, split_every=False)
+        return self.reduction(
+            chunk.var_chunk, partial(chunk.var_aggregate, ddof=ddof), split_every=False
+        )
 
     def std(self, ddof=0):
         """ Standard deviation """
@@ -1328,9 +1316,7 @@ class Bag(DaskMethodsMixin):
                 for i in range(self.npartitions)
             }
 
-        def combine2(acc, x):
-            return combine(acc, x[1])
-
+        combine2 = partial(chunk.foldby_combine2, combine)
         depth = 0
         k = self.npartitions
         b = a
@@ -1557,10 +1543,10 @@ class Bag(DaskMethodsMixin):
         >>> df = b.to_dataframe()
 
         >>> df.compute()
-           balance     name
-        0      100    Alice
-        1      200      Bob
-        0      300  Charlie
+              name  balance
+        0    Alice      100
+        1      Bob      200
+        0  Charlie      300
         """
         import pandas as pd
         import dask.dataframe as dd
@@ -1661,7 +1647,7 @@ class Bag(DaskMethodsMixin):
                     k = int(new - last)
                 dsk[(split_name, i)] = (split, (self.name, i), k)
                 for jj in range(k):
-                    dsk[(new_name, j)] = (getitem, (split_name, i), jj)
+                    dsk[(new_name, j)] = (operator.getitem, (split_name, i), jj)
                     j += 1
                 last = new
 
@@ -1893,10 +1879,9 @@ def from_delayed(values):
 
 
 def chunk_distinct(seq, key=None):
-    key2 = key
     if key is not None and not callable(key):
-        key2 = lambda x: x[key]
-    return list(unique(seq, key=key2))
+        key = partial(chunk.getitem, key=key)
+    return list(unique(seq, key=key))
 
 
 def merge_distinct(seqs, key=None):
@@ -2332,7 +2317,7 @@ def groupby_tasks(b, grouper, hash=hash, max_branch=32):
 
     inputs = [tuple(digit(i, j, k) for j in range(stages)) for i in range(k ** stages)]
 
-    b2 = b.map(lambda x: (hash(grouper(x)), x))
+    b2 = b.map(partial(chunk.groupby_tasks_group_hash, hash=hash, grouper=grouper))
 
     token = tokenize(b, grouper, hash, max_branch)
 
@@ -2430,10 +2415,7 @@ def groupby_disk(b, grouper, npartitions=None, blocksize=2 ** 20):
     # Barrier
     barrier_token = "groupby-barrier-" + token
 
-    def barrier(args):
-        return 0
-
-    dsk3 = {barrier_token: (barrier, list(dsk2))}
+    dsk3 = {barrier_token: (chunk.barrier,) + tuple(dsk2)}
 
     # Collect groups
     name = "groupby-collect-" + token
@@ -2483,20 +2465,21 @@ def random_sample(x, state_data, prob):
     ----------
     x : iterable
     state_data : tuple
-        A tuple that can be passed to ``random.Random``.
+        A tuple that can be passed to ``random.Random.setstate``.
     prob : float
         A float between 0 and 1, representing the probability that each
         element will be yielded.
     """
-    random_state = Random(state_data)
+    random_state = Random()
+    random_state.setstate(state_data)
     for i in x:
         if random_state.random() < prob:
             yield i
 
 
 def random_state_data_python(n, random_state=None):
-    """Return a list of tuples that can initialize.
-    ``random.Random``.
+    """Return a list of tuples that can be passed to
+    ``random.Random.setstate``.
 
     Parameters
     ----------
@@ -2510,7 +2493,12 @@ def random_state_data_python(n, random_state=None):
 
     maxuint32 = 1 << 32
     return [
-        tuple(random_state.randint(0, maxuint32) for i in range(624)) for i in range(n)
+        (
+            3,
+            tuple(random_state.randint(0, maxuint32) for i in range(624)) + (624,),
+            None,
+        )
+        for i in range(n)
     ]
 
 
