@@ -35,6 +35,7 @@ PANDAS_VERSION = LooseVersion(pd.__version__)
 PANDAS_GT_0230 = PANDAS_VERSION >= LooseVersion("0.23.0")
 PANDAS_GT_0240 = PANDAS_VERSION >= LooseVersion("0.24.0rc1")
 PANDAS_GT_0250 = PANDAS_VERSION >= LooseVersion("0.25.0")
+PANDAS_GT_100 = PANDAS_VERSION >= LooseVersion("0.26.0.dev0")
 HAS_INT_NA = PANDAS_GT_0240
 
 
@@ -382,7 +383,14 @@ def meta_nonempty_object(x):
 @meta_nonempty.register(pd.DataFrame)
 def meta_nonempty_dataframe(x):
     idx = meta_nonempty(x.index)
-    data = {i: _nonempty_series(x.iloc[:, i], idx=idx) for i, c in enumerate(x.columns)}
+    dt_s_dict = dict()
+    data = dict()
+    for i, c in enumerate(x.columns):
+        series = x.iloc[:, i]
+        dt = series.dtype
+        if dt not in dt_s_dict:
+            dt_s_dict[dt] = _nonempty_series(x.iloc[:, i], idx=idx)
+        data[i] = dt_s_dict[dt]
     res = pd.DataFrame(data, index=idx, columns=np.arange(len(x.columns)))
     res.columns = x.columns
     return res
@@ -641,13 +649,8 @@ def check_meta(x, meta, funcname=None, numeric_equal=True):
                 typename(type(meta)),
                 asciitable(["Column", "Found", "Expected"], bad_dtypes),
             )
-        elif not np.array_equal(np.nan_to_num(meta.columns), np.nan_to_num(x.columns)):
-            errmsg = (
-                "The columns in the computed data do not match"
-                " the columns in the provided metadata.\n"
-                " %s\n  :%s" % (meta.columns, x.columns)
-            )
         else:
+            check_matching_columns(meta, x)
             return x
     else:
         if equal_dtypes(x.dtype, meta.dtype):
@@ -663,6 +666,19 @@ def check_meta(x, meta, funcname=None, numeric_equal=True):
     )
 
 
+def check_matching_columns(meta, actual):
+    # Need nan_to_num otherwise nan comparison gives False
+    if not np.array_equal(np.nan_to_num(meta.columns), np.nan_to_num(actual.columns)):
+        extra = actual.columns.difference(meta.columns).tolist()
+        missing = meta.columns.difference(actual.columns).tolist()
+        raise ValueError(
+            "The columns in the computed data do not match"
+            " the columns in the provided metadata\n"
+            "  Extra:   %s\n"
+            "  Missing: %s" % (extra, missing)
+        )
+
+
 def index_summary(idx, name=None):
     """Summarized representation of an Index.
     """
@@ -936,3 +952,13 @@ def valid_divisions(divisions):
         return False
 
     return True
+
+
+def drop_by_shallow_copy(df, columns, errors="raise"):
+    """ Use shallow copy to drop columns in place
+    """
+    df2 = df.copy(deep=False)
+    if not pd.api.types.is_list_like(columns):
+        columns = [columns]
+    df2.drop(columns=columns, inplace=True, errors=errors)
+    return df2
